@@ -20,7 +20,7 @@ use App::Koyomi::Context;
 use App::Koyomi::JobTime::Formatter qw(str2time);
 use App::Koyomi::JobTime::Object;
 
-use version; our $VERSION = 'v0.4.0';
+use version; our $VERSION = 'v0.4.1';
 
 my @CLI_METHODS = qw/help man add list modify delete/;
 
@@ -200,7 +200,7 @@ sub delete {
         return;
     }
 
-    $ctx->datasource_job->delete_by_id(id => $job_id);
+    $ctx->datasource_job->delete_by_id(id => $job_id, ctx => $ctx);
 
     infof('[delete] Finished.');
 }
