@@ -5,11 +5,12 @@ use warnings;
 use 5.010_001;
 use Carp qw(croak);
 
-use version; our $VERSION = 'v0.4.0';
+use version; our $VERSION = 'v0.4.1';
 
-sub instance { croak 'Must implement in child class!'; }
-
-sub get_by_job_id { croak 'Must implement in child class!'; }
+sub instance         { croak 'Must implement in child class!'; }
+sub get_by_job_id    { croak 'Must implement in child class!'; }
+sub create           { croak 'Must implement in child class!'; }
+sub delete_by_job_id { croak 'Must implement in child class!'; }
 
 1;
 
@@ -27,6 +28,9 @@ B<App::Koyomi::DataSource::Semaphore> - Abstract datasource class for semaphore
 
     # Your implementation goes below
     sub instance { ... }
+    sub get_by_job_id { ... }
+    sub create { ... }
+    sub delete_by_job_id { ... }
 
 =head1 DESCRIPTION
 
@@ -41,6 +45,18 @@ Abstract datasource class for koyomi semaphore entity.
 Construct datasource object.
 Probably it's singleton.
 
+=item B<get_by_job_id>
+
+Fetch one semaphore by job_id.
+
+=item B<create>
+
+Create a semaphore.
+
+=item B<delete_by_job_id>
+
+Delete one semaphore specified by job_id.
+
 =back
 
 =head1 SEE ALSO
