@@ -6,6 +6,8 @@ use 5.010_001;
 use Class::Accessor::Lite (
     ro => [qw/teng/],
 );
+use DateTime::Format::MySQL;
+use Log::Minimal env_debug => 'KOYOMI_LOG_DEBUG';
 use Smart::Args;
 
 use App::Koyomi::DataSource::Semaphore::Teng::Data;
@@ -14,8 +16,9 @@ use App::Koyomi::DataSource::Semaphore::Teng::Schema;
 
 use parent qw(App::Koyomi::DataSource::Semaphore);
 
-use version; our $VERSION = 'v0.4.0';
+use version; our $VERSION = 'v0.4.1';
 
+my $TABLE = 'semaphores';
 my $DATASOURCE;
 
 sub instance {
@@ -46,7 +49,7 @@ sub get_by_job_id {
         my $job_id => 'Int',
         my $ctx    => 'App::Koyomi::Context',
     );
-    my $row = $self->teng->single('semaphores', +{job_id => $job_id});
+    my $row = $self->teng->single($TABLE, +{job_id => $job_id});
     return unless $row;
     return App::Koyomi::DataSource::Semaphore::Teng::Data->new(
         row => $row,
@@ -54,6 +57,61 @@ sub get_by_job_id {
     );
 }
 
+sub create {
+    args(
+        my $self,
+        my $job_id => 'Int',
+        my $ctx    => 'App::Koyomi::Context',
+        my $now    => +{ isa => 'DateTime', optional => 1 },
+    );
+    $now ||= $ctx->now;
+    my $teng = $self->teng;
+
+    # Transaction
+    my $txn = $teng->txn_scope;
+
+    my $now_db = DateTime::Format::MySQL->format_datetime($now);
+    eval {
+        my %semaphore = ( job_id => $job_id );
+        $semaphore{created_on} = $semaphore{updated_at} = $now_db;
+        unless ($teng->insert($TABLE, \%semaphore)) {
+            croakf(q/Insert %s Failed! data=%s/, $TABLE, ddf(\%semaphore));
+        }
+    };
+    if ($@) {
+        $txn->rollback;
+        die $@;
+    }
+
+    $txn->commit;
+    return 1;
+}
+
+sub delete_by_job_id {
+    args(
+        my $self,
+        my $job_id => 'Int',
+        my $ctx    => 'App::Koyomi::Context',
+    );
+    my $teng = $self->teng;
+
+    # Transaction
+    my $txn = $teng->txn_scope;
+
+    eval {
+        unless ($teng->delete($TABLE, +{ job_id => $job_id })) {
+            croakf(q/Delete %s Failed! job_id=%d/, $TABLE, $job_id);
+        }
+    };
+    if ($@) {
+        $txn->rollback;
+        die $@;
+    }
+
+    $txn->commit;
+    return 1;
+}
+
 1;
 
 __END__
